sequencetools.is_monotonically_decreasing_sequence
==================================================

.. autofunction:: abjad.tools.sequencetools.is_monotonically_decreasing_sequence.is_monotonically_decreasing_sequence
